SWDEV-299127 - Merge 'develop' into 'amd-staging'
Change-Id: I54aa4822132349d32cf912601adead0812c23230
This commit is contained in:
Vendored
+2
-2
@@ -57,7 +57,7 @@ def hipBuildTest(String backendLabel) {
|
||||
set -x
|
||||
# Check if backend label contains string "amd" or backend host is a server with amd gpu
|
||||
if [[ $backendLabel =~ amd ]]; then
|
||||
LLVM_PATH=/opt/rocm/llvm ctest
|
||||
LLVM_PATH=/opt/rocm/llvm ctest -E 'cooperative_streams_least_capacity.tst|cooperative_streams_half_capacity.tst|cooperative_streams_full_capacity.tst|grid_group_data_sharing.tst'
|
||||
else
|
||||
make test
|
||||
fi
|
||||
@@ -97,7 +97,7 @@ def hipBuildTest(String backendLabel) {
|
||||
set -x
|
||||
# Check if backend label contains string "amd" or backend host is a server with amd gpu
|
||||
if [[ $backendLabel =~ amd ]]; then
|
||||
LLVM_PATH=/opt/rocm/llvm ctest -E 'Unit_hipGraphChildGraphNodeGetGraph_Functional'
|
||||
LLVM_PATH=/opt/rocm/llvm ctest -E 'Unit_hipGraphChildGraphNodeGetGraph_Functional|Unit_hipGraphExecMemcpyNodeSetParamsFromSymbol_Negative'
|
||||
else
|
||||
make test
|
||||
fi
|
||||
|
||||
@@ -86,6 +86,7 @@ static inline void hipCheckAndFail(hipError_t errval,
|
||||
do { hipCheckAndFail((errval), __FILE__, __LINE__); } while (0)
|
||||
|
||||
__global__ void test_kernel(uint32_t loops, unsigned long long *array, long long totalTicks) {
|
||||
cooperative_groups::thread_block tb = cooperative_groups::this_thread_block();
|
||||
unsigned int rank = blockIdx.x * blockDim.x + threadIdx.x;
|
||||
|
||||
for (int i = 0; i < loops; i++) {
|
||||
@@ -100,6 +101,7 @@ __global__ void test_kernel(uint32_t loops, unsigned long long *array, long long
|
||||
// So just ignore those slipped cycles.
|
||||
last_clock = cur_clock;
|
||||
} while(time_diff < totalTicks);
|
||||
tb.sync();
|
||||
array[rank] += clock64();
|
||||
}
|
||||
}
|
||||
|
||||
Reference in New Issue
Block a user